@@ -17,7 +17,7 @@
 
 #include "gtr-translation-memory-dialog.h"
 #include "gtr-profile-manager.h"
-#include "gtr-utils.h"
+#include "gtr-translation-memory-utils.h"
 #include "gtr-po.h"
 
 #include <glib/gi18n.h>
@@ -52,11 +52,7 @@ gtr_translation_memory_dialog_dispose (GObject *object)
 {
   GtrTranslationMemoryDialogPrivate *priv = GTR_TRANSLATION_MEMORY_DIALOG (object)->priv;
 
-  if (priv->tm_settings != NULL)
-    {
-      g_object_unref (priv->tm_settings);
-      priv->tm_settings = NULL;
-    }
+  g_clear_object (&priv->tm_settings);
 
   G_OBJECT_CLASS (gtr_translation_memory_dialog_parent_class)->dispose (object);
 }
@@ -243,11 +239,11 @@ on_add_database_button_clicked (GtkButton                  *button,
 
       restriction = g_settings_get_string (dlg->priv->tm_settings,
                                            "filename-restriction");
-      gtr_utils_scan_dir (dir, &data->list, restriction);
+      gtr_scan_dir (dir, &data->list, restriction);
       g_free (restriction);
     }
   else
-    gtr_utils_scan_dir (dir, &data->list, NULL);
+    gtr_scan_dir (dir, &data->list, NULL);
 
   data->tm = dlg->priv->translation_memory;
   data->progress = GTK_PROGRESS_BAR (dlg->priv->add_database_progressbar);
