@@ -452,9 +452,6 @@ gtr_translation_memory_ui_init (GtrTranslationMemoryUi * tm_ui)
   priv->tree_view = gtk_tree_view_new ();
   gtk_widget_show (priv->tree_view);
 
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (tm_ui),
-                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-
   model = gtk_list_store_new (N_COLUMNS, G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING);
   gtk_tree_view_set_model (GTK_TREE_VIEW (priv->tree_view),
                            GTK_TREE_MODEL (model));
@@ -510,11 +507,7 @@ gtr_translation_memory_ui_dispose (GObject * object)
 
   DEBUG_PRINT ("Dispose translation memory ui");
 
-  if (tm_ui->priv->msg)
-    {
-      g_object_unref (tm_ui->priv->msg);
-      tm_ui->priv->msg = NULL;
-    }
+  g_clear_object (&tm_ui->priv->msg);
 
   G_OBJECT_CLASS (gtr_translation_memory_ui_parent_class)->dispose (object);
 }
