@@ -22,6 +22,10 @@
  *   Ignacio Casal Quinteiro <icq@gnome.org>
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtr-application.h"
 #include "gtr-header.h"
 #include "gtr-settings.h"
@@ -182,6 +186,13 @@ gtr_header_class_init (GtrHeaderClass * klass)
 
 /* Public methods */
 
+/**
+ * gtr_header_new: (skip)
+ * @iter:
+ * @message:
+ *
+ * Return value:
+ */
 GtrHeader *
 gtr_header_new (po_message_iterator_t iter, po_message_t message)
 {
@@ -713,6 +724,9 @@ gtr_header_update_header (GtrHeader * header)
 
   /* We need to unfuzzy the header to not produce errors */
   gtr_msg_set_fuzzy (GTR_MSG (header), FALSE);
+
+  /* Update X-Generator field */
+  gtr_header_set_field (header, "X-Generator", "Gtranslator "PACKAGE_VERSION);
 }
 
 void
